Function plan_idle_payout

pub fn plan_idle_payout(
    state: &VaultState,
    min_withdrawal_assets: u128,
) -> Result<IdlePayoutPlan, KernelError>
Plan an idle-funded payout from the current vault state.

Returns an error when the current idle liquidity cannot produce an actionable payout for the queue head.