pub fn preview_deposit_shares(
state: &VaultState,
config: &VaultConfig,
assets: u128,
) -> u128Expand description
Preview the shares minted for a deposit of assets using kernel conversions.
pub fn preview_deposit_shares(
state: &VaultState,
config: &VaultConfig,
assets: u128,
) -> u128Preview the shares minted for a deposit of assets using kernel conversions.