pub fn preview_withdraw_assets(
state: &VaultState,
config: &VaultConfig,
shares: u128,
) -> u128Expand description
Preview the assets redeemed for shares using kernel conversions.
pub fn preview_withdraw_assets(
state: &VaultState,
config: &VaultConfig,
shares: u128,
) -> u128Preview the assets redeemed for shares using kernel conversions.