pub enum RestrictionMode {
Blacklist(Vec<Address>),
Whitelist(Vec<Address>),
}Variants
Blacklist(Vec<Address>)
Blacklist - specified actors are blocked.
Whitelist(Vec<Address>)
Whitelist - only specified actors are allowed.
Implementations
Sourceimpl RestrictionMode
impl RestrictionMode
Sourcepub const fn is_blacklist(&self) -> bool
pub const fn is_blacklist(&self) -> bool
Returns true if this value is of type Blacklist. Returns false otherwise
Sourcepub const fn is_whitelist(&self) -> bool
pub const fn is_whitelist(&self) -> bool
Returns true if this value is of type Whitelist. Returns false otherwise
Sourceimpl RestrictionMode
impl RestrictionMode
pub fn blacklist(addresses: Vec<Address>) -> Self
pub fn whitelist(addresses: Vec<Address>) -> Self
pub fn normalized(self) -> Self
Sourcepub fn is_restricted(&self, actor_id: &Address) -> Option<RestrictionKind>
pub fn is_restricted(&self, actor_id: &Address) -> Option<RestrictionKind>
Check if the given actor is restricted.
Returns Some(kind) if blocked, None if allowed.
The returned RestrictionKind is a lightweight tag — no allocations.
Arguments
actor_id- The actor to check.
pub fn is_restricted_allowing_self( &self, actor_id: &Address, self_id: &Address, ) -> Option<RestrictionKind>