pub fn can_apply_settlement(
entry: &EscrowEntry,
settlement: &EscrowSettlement,
) -> boolExpand description
Validate that an escrow entry has sufficient shares for a settlement.
pub fn can_apply_settlement(
entry: &EscrowEntry,
settlement: &EscrowSettlement,
) -> boolValidate that an escrow entry has sufficient shares for a settlement.