pub fn compute_escrow_stats<'a, I>(entries: I) -> EscrowStatswhere
I: IntoIterator<Item = &'a EscrowEntry>,Expand description
Compute aggregate escrow statistics from an iterator of entries.
pub fn compute_escrow_stats<'a, I>(entries: I) -> EscrowStatswhere
I: IntoIterator<Item = &'a EscrowEntry>,Compute aggregate escrow statistics from an iterator of entries.