pub struct EscrowStats {
pub count: u32,
pub total_shares: u128,
pub total_expected_assets: u128,
}Expand description
Aggregate escrow statistics.
Fields
count: u32total_expected_assets: u128Trait Implementations
Sourceimpl BorshDeserialize for EscrowStats
impl BorshDeserialize for EscrowStats
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for EscrowStats
impl BorshSerialize for EscrowStats
Sourceimpl Clone for EscrowStats
impl Clone for EscrowStats
Sourcefn clone(&self) -> EscrowStats
fn clone(&self) -> EscrowStats
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EscrowStats
impl Debug for EscrowStats
Sourceimpl Default for EscrowStats
impl Default for EscrowStats
Sourcefn default() -> EscrowStats
fn default() -> EscrowStats
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EscrowStats
impl<'de> Deserialize<'de> for EscrowStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EscrowStats
impl PartialEq for EscrowStats
Sourceimpl Serialize for EscrowStats
impl Serialize for EscrowStats
impl Eq for EscrowStats
impl StructuralPartialEq for EscrowStats