pub struct WithdrawingState {
pub op_id: u64,
pub index: u32,
pub remaining: u128,
pub collected: u128,
pub receiver: Address,
pub owner: Address,
pub escrow_shares: u128,
}Expand description
Collecting liquidity from targets to satisfy a user withdrawal/redeem request.
Transitions
- Advance within queue:
Withdrawing(index increments) while collecting funds. - When enough is collected to satisfy the request:
Payout. - If the op is stopped or cannot proceed and needs to refund:
Idle(escrow_shares refunded).
Fields
op_id: u64index: u32remaining: u128collected: u128receiver: Addressowner: AddressImplementations