Function can_satisfy_withdrawal

pub fn can_satisfy_withdrawal(
    withdrawal: &PendingWithdrawal,
    available_assets: u128,
) -> bool
Check if a withdrawal can be satisfied given available assets.

A withdrawal can be satisfied if the available assets meet or exceed the expected asset amount from the withdrawal request.

Arguments

  • withdrawal - The pending withdrawal request.
  • available_assets - Assets currently available for withdrawal.