Struct FeeAccrualAnchor

pub struct FeeAccrualAnchor {
    pub total_assets: u128,
    pub timestamp_ns: TimestampNs,
}
Anchor point for fee accrual calculations.

Stores the total assets and timestamp at which fees were last accrued. Used to calculate time-weighted management fees and performance fees based on AUM growth.

Fields

total_assets: u128timestamp_ns: TimestampNs

Implementations

Source

impl FeeAccrualAnchor

pub const fn new(total_assets: u128, timestamp_ns: TimestampNs) -> Self

pub const fn zero() -> Self

pub fn update(&mut self, total_assets: u128, timestamp_ns: TimestampNs)