#[repr(transparent)]pub struct ExpectedIdx(pub u32);Expand description
Expected index in a queue or plan.
Tuple Fields
0: u32Trait Implementations
Sourceimpl BorshDeserialize for ExpectedIdx
impl BorshDeserialize for ExpectedIdx
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSchema for ExpectedIdx
impl BorshSchema for ExpectedIdx
Sourcefn declaration() -> Declaration
fn declaration() -> Declaration
Get the name of the type without brackets.
Sourcefn add_definitions_recursively(
definitions: &mut BTreeMap<Declaration, Definition>,
)
fn add_definitions_recursively( definitions: &mut BTreeMap<Declaration, Definition>, )
Recursively, using DFS, add type definitions required for this type.
Type definition partially explains how to serialize/deserialize a type.
Sourceimpl BorshSerialize for ExpectedIdx
impl BorshSerialize for ExpectedIdx
Sourceimpl Clone for ExpectedIdx
impl Clone for ExpectedIdx
Sourcefn clone(&self) -> ExpectedIdx
fn clone(&self) -> ExpectedIdx
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExpectedIdx
impl Debug for ExpectedIdx
Sourceimpl Default for ExpectedIdx
impl Default for ExpectedIdx
Sourcefn default() -> ExpectedIdx
fn default() -> ExpectedIdx
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExpectedIdx
impl<'de> Deserialize<'de> for ExpectedIdx
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ExpectedIdx
impl Display for ExpectedIdx
Sourceimpl From<ExpectedIdx> for u32
impl From<ExpectedIdx> for u32
Sourcefn from(value: ExpectedIdx) -> Self
fn from(value: ExpectedIdx) -> Self
Converts to this type from the input type.
Sourceimpl From<u32> for ExpectedIdx
impl From<u32> for ExpectedIdx
Sourceimpl Hash for ExpectedIdx
impl Hash for ExpectedIdx
Sourceimpl JsonSchema for ExpectedIdx
impl JsonSchema for ExpectedIdx
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExpectedIdx
impl Ord for ExpectedIdx
Sourcefn cmp(&self, other: &ExpectedIdx) -> Ordering
fn cmp(&self, other: &ExpectedIdx) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExpectedIdx
impl PartialEq for ExpectedIdx
Sourceimpl PartialOrd for ExpectedIdx
impl PartialOrd for ExpectedIdx
Sourceimpl Serialize for ExpectedIdx
impl Serialize for ExpectedIdx
impl Copy for ExpectedIdx
impl Eq for ExpectedIdx
impl StructuralPartialEq for ExpectedIdx