pub struct KernelVersion(pub u32);Expand description
Kernel version identifier.
Tuple Fields
0: u32Trait Implementations
Sourceimpl BorshDeserialize for KernelVersion
impl BorshDeserialize for KernelVersion
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for KernelVersion
impl BorshSerialize for KernelVersion
Sourceimpl Clone for KernelVersion
impl Clone for KernelVersion
Sourcefn clone(&self) -> KernelVersion
fn clone(&self) -> KernelVersion
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KernelVersion
impl Debug for KernelVersion
Sourceimpl<'de> Deserialize<'de> for KernelVersion
impl<'de> Deserialize<'de> for KernelVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<KernelVersion> for u32
impl From<KernelVersion> for u32
Sourcefn from(value: KernelVersion) -> Self
fn from(value: KernelVersion) -> Self
Converts to this type from the input type.
Sourceimpl From<u32> for KernelVersion
impl From<u32> for KernelVersion
Sourceimpl PartialEq for KernelVersion
impl PartialEq for KernelVersion
Sourceimpl Serialize for KernelVersion
impl Serialize for KernelVersion
impl Copy for KernelVersion
impl Eq for KernelVersion
impl StructuralPartialEq for KernelVersion