Function plan_idle_payout

pub fn plan_idle_payout(
    state: &VaultState,
) -> Result<Option<IdlePayoutPlan>, KernelError>
Plan an idle-funded payout from the current vault state.

Returns Ok(None) when the vault is in a valid withdrawing state but there is not enough idle liquidity to satisfy the queue head yet.